@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::FeedReader;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 use Mojo::Util qw(decode trim);
 use Mojo::File;
 use Mojo::DOM;
@@ -196,12 +196,25 @@ sub parse_rss_item {
     }
   }
 
+  $item->find('enclosure')->each(
+    sub {
+        push @{ $h{enclosures} }, shift->attr;
+    }
+  );  
+
   # let's handle links seperately, because ATOM loves these buggers:
   $item->find('link')->each(
     sub {
       my $l = shift;
       if ($l->attr('href')) {
-        if (!$l->attr('rel') || $l->attr('rel') eq 'alternate') {
+	if ( $l->attr('rel' ) && $l->attr('rel') eq 'enclosure' ) {
+                push @{$h{enclosures}}, {
+                    url    => $l->attr('href'),
+                    type   => $l->attr('type'),
+                    length => $l->attr('length')
+                };
+	}
+        elsif (!$l->attr('rel') || $l->attr('rel') eq 'alternate') {
           $h{'link'} = $l->attr('href');
         }
       }
@@ -546,6 +559,8 @@ Each item in the items array is a hashref with the following keys:
 
 =item * _raw - XML serialized text of the item's Mojo::DOM node. Note that this can be different from the original XML text in the feed.
 
+=item * enclosures (optional) - array ref of enclosures, each a hashref with the keys url, type and length.
+
 =back
 
 =head2 parse_opml
